<script setup lang="ts">
import TitlePanel from "@/views/ecg/doctor/components/TitlePanel.vue";
import QueuePanel from "@/views/ecg/doctor/components/QueuePanel.vue";
import { DoctorApi, RoomBedVO } from '@/api/ecg/doctor';
import {useUserStore} from "@/store/modules/user";
import {queueVO} from "@/api/ecg/queue";

const userStore = useUserStore();

const roomBedVO: RoomBedVO = {
    roomId: userStore.room.roomId,
    bedNo: userStore.room.bedNo
}

const list = ref<queueVO[]>([])

const finishNextPatient = async () => {
  const data = await DoctorApi.finishNextPatient(roomBedVO)
  list.value = data
}

const passNextPatient = async () => {
    const data = await DoctorApi.passNextPatient(roomBedVO)
    list.value = data
}

const getPatientList = async () => {
    const data = await DoctorApi.getPatientList(roomBedVO)
    list.value = data
}

/** 初始化 **/
onMounted(() => {
    getPatientList()
})

</script>

<template>
  <el-container>
    <el-header style="background-color: var(--el-color-primary-light-7); font-size: 24px">
      <TitlePanel room="A208"/>
    </el-header>
    <el-container>
      <el-main>
        装机界面
      </el-main>
      <el-aside width="300px" style="background-color: var(--el-color-primary-light-7);">
        <QueuePanel :queue="list"/>
      </el-aside>
    </el-container>
    <el-container style="justify-content: center;">
      <el-button type="primary" @click="finishNextPatient">完成下一位</el-button>
      <el-button type="primary" @click="passNextPatient">过号下一位</el-button>
    </el-container>
  </el-container>
</template>

<style scoped lang="scss">

</style>
